@@ -1,12 +1,12 @@
 ### mvr_wrappers.R: plsr, pls and pcr wrappers for mvr
-### $Id: mvr_wrappers.R 203 2011-11-27 14:16:11Z bhm $
+### $Id: mvr_wrappers.R 229 2013-07-13 13:15:25Z bhm $
 
 plsr <- function(..., method = pls.options()$plsralg)
 {
     cl <- match.call()
     cl$method <- match.arg(method, c("kernelpls", "widekernelpls", "simpls",
                                      "oscorespls", "model.frame"))
-    cl[[1]] <- as.name("mvr")
+    cl[[1]] <- quote(pls::mvr)
     res <- eval(cl, parent.frame())
     ## Fix call component
     if (cl$method != "model.frame") res$call[[1]] <- as.name("plsr")
@@ -18,7 +18,7 @@ pcr <- function(..., method = pls.options()$pcralg)
 {
     cl <- match.call()
     cl$method <- match.arg(method, c("svdpc", "model.frame"))
-    cl[[1]] <- as.name("mvr")
+    cl[[1]] <- quote(pls::mvr)
     res <- eval(cl, parent.frame())
     ## Fix call component
     if (cl$method != "model.frame") res$call[[1]] <- as.name("pcr")
@@ -30,7 +30,7 @@ cppls <- function(..., Y.add, weights, method = pls.options()$cpplsalg)
 {
     cl <- match.call()
     cl$method <- match.arg(method, c("cppls", "model.frame"))
-    cl[[1]] <- as.name("mvr")
+    cl[[1]] <- quote(pls::mvr)
     res <- eval(cl, parent.frame())
     ## Fix call component
     if (cl$method != "model.frame") res$call[[1]] <- as.name("cppls")
